@@ -6,8 +6,6 @@ from trytond.model import Workflow, ModelView
 from trytond.pool import Pool, PoolMeta
 from trytond.transaction import Transaction
 
-__all__ = ['Move']
-
 
 class Move(metaclass=PoolMeta):
     __name__ = 'stock.move'
@@ -19,17 +17,15 @@ class Move(metaclass=PoolMeta):
         pool = Pool()
         Uom = pool.get('product.uom')
         AccountMoveLine = pool.get('account.move.line')
-        Currency = pool.get('currency.currency')
         assert type_.startswith('in_') or type_.startswith('out_'), \
             'wrong type'
 
         move_line = AccountMoveLine()
-        if ((type_.endswith('supplier')
-                    or type_ == 'in_production')
+        if ((
+                    type_.endswith('supplier')
+                    or type_ in {'in_production', 'in_warehouse'})
                 and self.product.cost_price_method != 'fixed'):
-            with Transaction().set_context(date=self.effective_date):
-                unit_price = Currency.compute(self.currency, self.unit_price,
-                    self.company.currency, round=False)
+            unit_price = self.unit_price_company
         else:
             unit_price = Uom.compute_price(self.product.default_uom,
                 self.cost_price, self.uom)
@@ -39,14 +35,11 @@ class Move(metaclass=PoolMeta):
         if type_.startswith('in_'):
             move_line.debit = Decimal('0.0')
             move_line.credit = amount
-            account_type = type_[3:]
+            move_line.account = self.product.account_stock_in_used
         else:
             move_line.debit = amount
             move_line.credit = Decimal('0.0')
-            account_type = type_[4:]
-
-        move_line.account = getattr(self.product,
-            'account_stock_%s_used' % account_type)
+            move_line.account = self.product.account_stock_out_used
 
         return [move_line]
 
@@ -117,7 +110,8 @@ class Move(metaclass=PoolMeta):
         type_ = self._get_account_stock_move_type()
         if not type_:
             return
-        with Transaction().set_context(date=date):
+        with Transaction().set_context(
+                company=self.company.id, date=date):
             if type_ == 'supplier_customer':
                 account_move_lines = self._get_account_stock_move_lines(
                     'in_supplier')
@@ -134,13 +128,18 @@ class Move(metaclass=PoolMeta):
         amount = Decimal('0.0')
         for line in account_move_lines:
             amount += line.debit - line.credit
+
+        if not amount:
+            return
         move_line = self._get_account_stock_move_line(amount)
         if move_line:
             account_move_lines.append(move_line)
 
         account_configuration = AccountConfiguration(1)
+        journal = account_configuration.get_multivalue(
+            'stock_journal', company=self.company.id)
         return AccountMove(
-            journal=account_configuration.stock_journal,
+            journal=journal,
             period=period_id,
             date=date,
             origin=self,
